@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import uuid
 import abc
-from copy import deepcopy
 
 
 class StateKey:
@@ -21,29 +20,33 @@ class StateKey:
 
 
 class StateVar(abc.ABC):
+  """
+  Representation of a state variable involved in the optimization problem, subclass defines what the state represents
+  and the current value of the state. This class should serve as a wrapper of the variable so never create its own copy
+  of the variable.
+  """
 
-  def __init__(self, value, perturb_dim: int, *, is_locked: bool = False, copy: bool = False):
-    assert perturb_dim > 0, "Zero or negative pertubation dimension."
-    self._value = deepcopy(value) if copy else value
+  def __init__(self, perturb_dim: int, *, is_locked: bool = False):
+    assert perturb_dim > 0, "Zero or negative perturbation dimension."
     self._perturb_dim: int = perturb_dim
     self._is_locked: bool = is_locked
     self._key: StateKey = StateKey()
 
   @abc.abstractmethod
-  def update(self):
-    pass
+  def clone(other: StateVar):
+    """Creats a copy of this state variable including its current value"""
 
   @abc.abstractmethod
   def get_value(self):
-    pass
+    """Returns a reference to the internal value"""
 
   @abc.abstractmethod
   def set_value(self, value):
-    pass
+    """Sets internal value from another internal value"""
 
   @abc.abstractmethod
-  def clone(other: StateVar):
-    pass
+  def update(self, perturbation):
+    """Update value given a perturbation"""
 
   def set_from_copy(self, other: StateVar) -> None:
     assert self.get_key() == other.get_key()
